@@ -48,7 +48,7 @@ timeout_cb (gpointer data)
 	GdkPixbuf * pixbuf = gdk_pixbuf_new_from_file(lastpath, NULL);
 	g_return_val_if_fail(pixbuf != NULL, TRUE);
 
-	indicate_indicator_set_property_icon(INDICATE_INDICATOR(indicator), "icon", pixbuf);
+	indicate_gtk_indicator_set_property_icon(INDICATE_INDICATOR(indicator), "icon", pixbuf);
 	g_object_unref(G_OBJECT(pixbuf));
 
 	return TRUE;
