@@ -37,7 +37,7 @@ License version 3 and version 2.1 along with this program.  If not, see
 G_BEGIN_DECLS
 
 /* Properties handling */
-void indicate_indicator_set_property_icon (IndicateIndicator * indicator, const gchar * key, const GdkPixbuf * data);
+void indicate_gtk_indicator_set_property_icon (IndicateIndicator * indicator, const gchar * key, const GdkPixbuf * data);
 
 G_END_DECLS
 
