@@ -28,7 +28,8 @@ License version 3 and version 2.1 along with this program.  If not, see
 #ifndef INDICATE_DBUS_SHARED
 #define INDICATE_DBUS_SHARED
 
-#define  INDICATE_DBUS_IFACE            "org.ayatana.indicate"
-#define  INDICATE_LISTENER_DBUS_IFACE   "org.ayatana.indicate.listener"
+#define  INDICATE_DBUS_IFACE            "com.canonical.indicate"
+#define  INDICATE_LISTENER_DBUS_IFACE   "com.canonical.indicate.listener"
+#define  INDICATE_LISTENER_OBJ_PATH     "/com/canonical/indicate/listener"
 
 #endif /* INDICATE_DBUS_SHARED */
