@@ -27,8 +27,7 @@ License version 3 and version 2.1 along with this program.  If not, see
 <http://www.gnu.org/licenses/>
 */
 
-#include "glib.h"
-#include "glib/gmessages.h"
+#include <glib.h>
 #include "indicator.h"
 #include "server.h"
 
@@ -202,6 +201,8 @@ indicate_indicator_finalize (GObject * obj)
 	IndicateIndicator * indicator = INDICATE_INDICATOR(obj);
 	IndicateIndicatorPrivate * priv = INDICATE_INDICATOR_GET_PRIVATE(indicator);
 
+	g_hash_table_destroy (priv->properties);
+
 	indicate_server_remove_indicator(priv->server, indicator);
 	g_object_unref(priv->server);
 	priv->server = NULL;
@@ -569,7 +570,7 @@ set_property (IndicateIndicator * indicator, const gchar * key, GVariant * data)
 
 	gchar * newkey = g_strdup(key);
 	if (data != NULL) {
-		g_variant_ref(data);
+		g_variant_ref_sink(data);
 	}
 
 	g_hash_table_replace(priv->properties, newkey, data);
