@@ -30,6 +30,9 @@ License version 3 and version 2.1 along with this program.  If not, see
 #ifndef INDICATE_LISTENER_PRIVATE_H__ 
 #define INDICATE_LISTENER_PRIVATE_H__ 1
 
+#include <glib.h>
+#include <gio/gio.h>
+
 struct _IndicateListenerServer {
 	gchar * name;
 	GDBusProxy * proxy;
