@@ -106,9 +106,9 @@ static gboolean todo_idle (gpointer data);
 static void set_max_indicators_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void get_type_initial_cb (IndicateListener * listener, IndicateListenerServer * server, const gchar * type, gpointer data);
 static void get_type_cb (IndicateListener * listener, IndicateListenerServer * server, const gchar * type, gpointer data);
-static void proxy_indicator_added_legacy (guint id, gchar * type, proxy_t * proxyt);
+static void proxy_indicator_added_legacy (guint id, const gchar * type, proxy_t * proxyt);
 static void proxy_indicator_added (guint id, proxy_t * proxyt);
-static void proxy_indicator_removed_legacy (guint id, gchar * type, proxy_t * proxyt);
+static void proxy_indicator_removed_legacy (guint id, const gchar * type, proxy_t * proxyt);
 static void proxy_indicator_removed (guint id, proxy_t * proxyt);
 static void proxy_indicator_modified (guint id, const gchar * property, proxy_t * proxyt);
 static void proxy_server_count_changed (guint count, proxy_t * proxyt);
@@ -117,7 +117,7 @@ static void proxy_destroyed (GObject * proxy, gpointer user_data);
 static void bus_method_call (GDBusConnection * connection, const gchar * sender, const gchar * path, const gchar * interface, const gchar * method, GVariant * params, GDBusMethodInvocation * invocation, gpointer user_data);
 static void bus_get_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void bus_filter_show_server (GDBusConnection * connection, const gchar * sender, const gchar * object, const gchar * interface, const gchar * signal, GVariant * params, gpointer user_data);
-static void prox_ready_cb (GObject * object, GAsyncResult * res, gpointer user_data);
+static void proxy_ready_cb (GObject * object, GAsyncResult * res, gpointer user_data);
 static void proxy_signal_cb (GDBusProxy * proxy, gchar * sender, gchar * signal, GVariant * params, gpointer user_data);
 
 /* Bus Stuff */
@@ -382,7 +382,7 @@ bus_get_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 	return;
 }
 
-/* Handle a metho call from dbus */
+/* Handle a method call from dbus */
 static void
 bus_method_call (GDBusConnection * connection, const gchar * sender, const gchar * path, const gchar * interface, const gchar * method, GVariant * params, GDBusMethodInvocation * invocation, gpointer user_data)
 {
@@ -486,21 +486,10 @@ proxy_struct_destroy (gpointer data)
 		proxy_data->dbus_listener_sub = 0;
 	}
 
-	if (proxy_data->proxy != NULL) {
-		g_object_unref(G_OBJECT(proxy_data->proxy));
-	}
-
-	if (proxy_data->name != NULL) {
-		g_free(proxy_data->name);
-	}
-
-	if (proxy_data->path != NULL) {
-		g_free(proxy_data->path);
-	}
-
-	if (proxy_data->type != NULL) {
-		g_free(proxy_data->type);
-	}
+	g_clear_object(&proxy_data->proxy);
+	g_free(proxy_data->name);
+	g_free(proxy_data->path);
+	g_free(proxy_data->type);
 	g_free(proxy_data);
 
 	return;
@@ -612,10 +601,10 @@ todo_idle (gpointer data)
 	                 G_DBUS_PROXY_FLAGS_NONE,
 	                 bus_indicate_interface_info,
 	                 proxyt->name,
-	                 todo->path,
+	                 proxyt->path,
 	                 INDICATE_DBUS_IFACE,
 	                 NULL, /* cancel */
-	                 prox_ready_cb,
+	                 proxy_ready_cb,
 	                 proxyt);
 
 	return TRUE; /* do the next entry */
@@ -623,7 +612,7 @@ todo_idle (gpointer data)
 
 /* Async result of building a proxy */
 static void
-prox_ready_cb (GObject * object, GAsyncResult * res, gpointer user_data)
+proxy_ready_cb (GObject * object, GAsyncResult * res, gpointer user_data)
 {
 	proxy_t * proxyt = (proxy_t *)user_data;
 	GError * error = NULL;
@@ -697,24 +686,24 @@ proxy_signal_cb (GDBusProxy * proxy, gchar * sender, gchar * signal, GVariant *
 	proxy_t * proxyt = (proxy_t *)user_data;
 
 	if (g_strcmp0(signal, "IndicatorAdded") == 0) {
-		guint id; gchar * type;
-		g_variant_get(params, "(us)", &id, &type);
+		guint id; const gchar * type;
+		g_variant_get(params, "(u&s)", &id, &type);
 		proxy_indicator_added_legacy(id, type, proxyt);
 	} else if (g_strcmp0(signal, "IndicatorNew") == 0) {
 		guint id;
 		g_variant_get(params, "(u)", &id);
 		proxy_indicator_added(id, proxyt);
 	} else if (g_strcmp0(signal, "IndicatorRemoved") == 0) {
-		guint id; gchar * type;
-		g_variant_get(params, "(us)", &id, &type);
+		guint id; const gchar * type;
+		g_variant_get(params, "(u&s)", &id, &type);
 		proxy_indicator_removed_legacy(id, type, proxyt);
 	} else if (g_strcmp0(signal, "IndicatorDelete") == 0) {
 		guint id;
 		g_variant_get(params, "(u)", &id);
 		proxy_indicator_removed(id, proxyt);
 	} else if (g_strcmp0(signal, "IndicatorModified") == 0) {
-		guint id; gchar * property;
-		g_variant_get(params, "(us)", &id, &property);
+		guint id; const gchar * property;
+		g_variant_get(params, "(u&s)", &id, &property);
 		proxy_indicator_modified(id, property, proxyt);
 	} else if (g_strcmp0(signal, "ServerCountChanged") == 0) {
 		guint count;
@@ -761,11 +750,7 @@ get_type_cb (IndicateListener * listener, IndicateListenerServer * server, const
 	}
 
 	proxy_t * proxyt = (proxy_t *)data;
-
-	if (proxyt->type != NULL) {
-		g_free(proxyt->type);
-		proxyt->type = NULL;
-	}
+	g_free (proxyt->type);
 	proxyt->type = g_strdup(type);
 
 	return;
@@ -825,7 +810,7 @@ proxy_get_indicator_list (GObject * object, GAsyncResult * res, gpointer data)
    signals on the indicator v1 interface.  It just drops
    the type and calls the new function. */
 static void
-proxy_indicator_added_legacy (guint id, gchar * type, proxy_t * proxyt)
+proxy_indicator_added_legacy (guint id, const gchar * type, proxy_t * proxyt)
 {
 	return proxy_indicator_added(id, proxyt);
 }
@@ -853,7 +838,7 @@ proxy_indicator_added (guint id, proxy_t * proxyt)
    signals on the indicator v1 interface.  It just drops
    the type and calls the new function. */
 static void
-proxy_indicator_removed_legacy (guint id, gchar * type, proxy_t * proxyt)
+proxy_indicator_removed_legacy (guint id, const gchar * type, proxy_t * proxyt)
 {
 	return proxy_indicator_removed(id, proxyt);
 }
