@@ -193,9 +193,14 @@ void                  indicate_listener_server_get_menu    (IndicateListener * l
                                                             IndicateListenerServer * server,
                                                             void (*callback) (IndicateListener * listener, IndicateListenerServer * server, const gchar * value, gpointer data),
                                                             gpointer data);
+void                  indicate_listener_server_get_icon_theme (IndicateListener * listener,
+							       IndicateListenerServer * server,
+							       void (*callback) (IndicateListener *listener, IndicateListenerServer *server, const gchar *value, gpointer data),
+							       gpointer data);
 GList *               indicate_listener_server_get_indicators    (IndicateListener * listener,
                                                                   IndicateListenerServer * server);
 const gchar *         indicate_listener_server_get_dbusname      (IndicateListenerServer * server);
+const gchar *         indicate_listener_server_get_dbuspath      (IndicateListenerServer *server);
 guint                 indicate_listener_indicator_get_id         (IndicateListenerIndicator * indicator);
 void                  indicate_listener_server_show_interest     (IndicateListener * listener,
                                                                   IndicateListenerServer * server,
