@@ -576,6 +576,7 @@ indicate_server_dispose (GObject * obj)
 		priv->interest_timer = 0;
 	}
 
+	G_OBJECT_CLASS (indicate_server_parent_class)->dispose (obj);
 	return;
 }
 
@@ -585,15 +586,10 @@ indicate_server_finalize (GObject * obj)
 	IndicateServer * server = INDICATE_SERVER(obj);
 	IndicateServerPrivate * priv = INDICATE_SERVER_GET_PRIVATE(server);
 
-	if (priv->path) {
-		g_free(priv->path);
-	}
-	if (priv->desktop) {
-		g_free(priv->desktop);
-	}
-	if (priv->type) {
-		g_free(priv->type);
-	}
+	g_free(priv->path);
+	g_free(priv->desktop);
+	g_free(priv->type);
+	g_free(priv->icon_theme);
 
 	G_OBJECT_CLASS (indicate_server_parent_class)->finalize (obj);
 
@@ -608,15 +604,11 @@ set_property (GObject * obj, guint id, const GValue * value, GParamSpec * pspec)
 	IndicateServerPrivate * priv = INDICATE_SERVER_GET_PRIVATE(obj);
 	switch (id) {
 	case PROP_DESKTOP:
-		if (priv->desktop != NULL) {
-			g_free(priv->desktop);
-		}
+		g_free(priv->desktop);
 		priv->desktop = g_value_dup_string(value);
 		break;
 	case PROP_TYPE:
-		if (priv->type != NULL) {
-			g_free(priv->type);
-		}
+		g_free(priv->type);
 		priv->type = g_value_dup_string(value);
 		break;
 	case PROP_COUNT: {
@@ -637,15 +629,11 @@ set_property (GObject * obj, guint id, const GValue * value, GParamSpec * pspec)
 		break;
 	}
 	case PROP_PATH:
-	        if (priv->path != NULL) {
-	                g_free(priv->path);
-	        }
-	        priv->path = g_value_dup_string(value);
-	        break;
+		g_free(priv->path);
+		priv->path = g_value_dup_string(value);
+		break;
 	case PROP_ICON_THEME:
-		if (priv->icon_theme != NULL) {
-			g_free (priv->icon_theme);
-		}
+		g_free (priv->icon_theme);
 		priv->icon_theme = g_value_dup_string(value);
 		break;
 	default:
